<?php
/**
 * gallery Section options
 *
 * @package Theme Palace
 * @subpackage Coast
 * @since Coast 1.0.0
 */

// Add gallery section
$wp_customize->add_section( 'coast_gallery_section', array(
	'title'             => esc_html__( 'Gallery','coast' ),
	'description'       => esc_html__( 'Gallery Section options.', 'coast' ),
	'panel'             => 'coast_front_page_panel',
) );

// gallery content enable control and setting
$wp_customize->add_setting( 'coast_theme_options[gallery_section_enable]', array(
	'default'			=> 	$options['gallery_section_enable'],
	'sanitize_callback' => 'coast_sanitize_switch_control',
) );

$wp_customize->add_control( new Coast_Switch_Control( $wp_customize, 'coast_theme_options[gallery_section_enable]', array(
	'label'             => esc_html__( 'Gallery Section Enable', 'coast' ),
	'section'           => 'coast_gallery_section',
	'on_off_label' 		=> coast_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'coast_theme_options[gallery_section_enable]', array(
		'selector'            => '#coast_gallery_section .tooltiptext',
		'settings'            => 'coast_theme_options[gallery_section_enable]',
    ) );
}

// Sub Title setting and control
$wp_customize->add_setting( 'coast_theme_options[gallery_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default' => $options['gallery_sub_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'coast_theme_options[gallery_sub_title]', array(
	'label'             => sprintf( esc_html__( 'Section Sub Title', 'coast' ) ),
	'section'        	=> 'coast_gallery_section',
	'active_callback' 	=> 'coast_is_gallery_section_enable',
	'type'				=> 'text',
	) );

	// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'coast_theme_options[gallery_sub_title]', array(
		'selector'            => '#coast-gallery .section-header p.section-subtitle',
		'settings'            => 'coast_theme_options[gallery_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'coast_gallery_sub_title_partial',
    ) );
}

// Title setting and control
$wp_customize->add_setting( 'coast_theme_options[gallery_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default' => $options['gallery_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'coast_theme_options[gallery_title]', array(
	'label'             => sprintf( esc_html__( 'Section Title', 'coast' ) ),
	'section'        	=> 'coast_gallery_section',
	'active_callback' 	=> 'coast_is_gallery_section_enable',
	'type'				=> 'text',
	) );

	// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'coast_theme_options[gallery_title]', array(
		'selector'            => '#coast-gallery h2.section-title',
		'settings'            => 'coast_theme_options[gallery_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'coast_gallery_title_partial',
    ) );
}

	// gallery count is 6 as of now
for ( $i = 1; $i <= $options['gallery_count']; $i++ ) :

	$wp_customize->add_setting( 'coast_theme_options[gallery_image_' .$i. ']', array(
		'sanitize_callback' => 'coast_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'coast_theme_options[gallery_image_' .$i. ']',
			array(
			'label'       		=> esc_html__( 'Gallery Image ', 'coast' ).$i,
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'coast' ), 650, 700 ),
			'section'     		=> 'coast_gallery_section',
			'active_callback'	=> 'coast_is_gallery_section_enable',
	) ) );

endfor;


